boofun.analysis
=================

.. automodule:: boofun.analysis


   .. rubric:: Classes

   .. autosummary::

      PropertyTester
      SpectralAnalyzer

.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   arrow
   basic_properties
   block_sensitivity
   canalization
   certificates
   complexity
   equivalence
   fkn
   fourier
   gaussian
   gf2
   global_hypercontractivity
   huang
   hypercontractivity
   invariance
   learning
   ltf_analysis
   p_biased
   pac_learning
   query_complexity
   restrictions
   sensitivity
   symmetry
